#!/bin/bash

# ComChecker Linux & Mac v 0.3f Copyright 2008, Brandon Jenkins
# This is the same script used on the OS X version with exception to the inclusion of the
# user defined settings. It is a separate file on the Mac. 

# Defaults and config options for Linux
#Simultaneous comskip executions
SIMUL=5

#Path to wine inside of the wine.bundle
WINEPATH=/usr/bin

#Path to comskip.exe and ini.
CSPATH=/opt/sagetv/comskip

#Path to tv files. Space delimited for multiples.
TVPATH=( /var/media/tv )

#Video file types to scan
VTYPE=( mpg )

#Comskip files to look for
CHKEXT=( txt log edl xml )

#If files exist with these extentions, keep all files related to video
KEEP=( ts mpg mp4 ps )

#Set the interval for checking the directory. Recommend 60 seconds. Live scanning is faster.
DELAY=60

if [[ $1 ]]; then . $1; fi

if [ -e "$WINEPATH/Wine.bundle" ]; then APPLE_APP="Wine.bundle/Contents/bin/"; fi

while [ 1 ] ; do
	for (( x = 0 ; x < ${#TVPATH[@]} ; x++ )); do
		echo
		echo "Processing Videos in ${TVPATH[$x]}.."
		echo
		for (( n = 0 ; n < ${#VTYPE[@]} ; n++ )); do
			echo "	Checking for ${VTYPE[$n]} videos."
			for VIDEO in $(find ${TVPATH[$x]} -type f \( -name "*.${VTYPE[$n]}" \)); do
				#echo "		Found $VIDEO checking processed..."
				PROCESSED=0
				EPISODE=`basename $VIDEO | cut -d'.' -f1`
				for (( i = 0 ; i < ${#CHKEXT[@]} ; i++ )); do
					if [ -f "${TVPATH[$x]}/$EPISODE.${CHKEXT[$i]}" ]; then
						#echo "			Already processed."
						PROCESSED=1
					fi
				done
				if [ ! $PROCESSED -eq 1 ]; then
					if [ $SIMUL -gt `ps -ef | grep comskip | grep -v grep | wc -l | sed 's/ //g'` ]; then
						if [ -f "$VIDEO" ]; then
							echo "			Run Comskip on $VIDEO"
							nohup "$WINEPATH/${APPLE_APP}wine" "$CSPATH/comskip.exe" --ini="$CSPATH/comskip.ini" "$VIDEO" 2>/dev/null 1>/dev/null &
						fi
					else
					    echo "			Waiting for other Comskip to finish."
					fi
				fi
			done
			echo 
		done
	
		echo "Looking for old files..."
		FILE_LIST=$(find ${TVPATH[$x]} -name `echo ${CHKEXT[*]} | sed 's/ / -o -name *./g'` | sed 's/.*\///' | cut -d '.' -f1 | uniq)
		for DELME in $FILE_LIST
		do
			FILE_EXIST=0
			for (( KEEPME = 0 ; KEEPME < ${#KEEP[@]} ; KEEPME++ )); do
				if [[ -f ${TVPATH[$x]}/$DELME.${KEEP[$KEEPME]} ]]; then
					#echo "Found ${TVPATH[$x]}/$DELME.${KEEP[$KEEPME]}"
					FILE_EXIST=1
				fi
			done
			if [ $FILE_EXIST == 0 ]; then
				echo "	Removing $DELME.*"
				rm ${TVPATH[$x]}/$DELME.*
			fi	
		done
	done
	echo
	echo "Waiting for $DELAY seconds"
	sleep $DELAY
done
